#!/usr/bin/env python

# Map Slack emojis to Discord's versions where they don't automatically convert
# Note that dashes in Slack emojis need to be converted to underscores before this can be used
GLOBAL_EMOJI_MAP = {
    "badminton_racquet_and_shuttlecock": "badminton",
    "bald_man": "man_bald",
    "bald_person": "person_bald",
    "bald_woman": "woman_bald",
    "barely_sunny": "white_sun_cloud",
    "black_circle_for_record": "record_button",
    "black_left_pointing_double_triangle_with_vertical_bar": "track_previous",
    "black_right_pointing_double_triangle_with_vertical_bar": "track_next",
    "black_right_pointing_triangle_with_double_vertical_bar": "play_pause",
    "black_square_for_stop": "stop_button",
    "boat": "sailboat",
    "bride_with_veil": "person_with_veil",
    "car": "red_car",
    "clinking_glasses": "champagne_glass",
    "cn": "flag_cn",
    "collision": "boom",
    "cricket_bat_and_ball": "cricket_game",
    "crossed_fingers": "fingers_crossed",
    "curly_haired_man": "man_curly_haired",
    "curly_haired_person": "person_curly_hair",
    "curly_haired_woman": "woman_curly_haired",
    "de": "flag_de",
    "email": "envelope",
    "es": "flag_es",
    "face_with_finger_covering_closed_lips": "shushing_face",
    "face_with_one_eyebrow_raised": "face_with_raised_eyebrow",
    "face_with_open_mouth_vomiting": "face_vomiting",
    "face_with_symbols_on_mouth": "face_with_symbols_over_mouth",
    "facepunch": "punch",
    "female_artist": "woman_artist",
    "female_astronaut": "woman_astronaut",
    "female_construction_worker": "woman_construction_worker",
    "female_cook": "woman_cook",
    "female_detective": "woman_detective",
    "female_doctor": "woman_health_worker",
    "female_elf": "woman_elf",
    "female_factory_worker": "woman_factory_worker",
    "female_fairy": "woman_fairy",
    "female_farmer": "woman_farmer",
    "female_firefighter": "woman_firefighter",
    "female_genie": "woman_genie",
    "female_guard": "woman_guard",
    "female_judge": "woman_judge",
    "female_mage": "woman_mage",
    "female_mechanic": "woman_mechanic",
    "female_office_worker": "woman_office_worker",
    "female_pilot": "woman_pilot",
    "female_police_officer": "woman_police_officer",
    "female_scientist": "woman_scientist",
    "female_singer": "woman_singer",
    "female_student": "woman_student",
    "female_superhero": "woman_superhero",
    "female_supervillain": "woman_supervillain",
    "female_teacher": "woman_teacher",
    "female_technologist": "woman_technologist",
    "female_vampire": "woman_vampire",
    "female_zombie": "woman_zombie",
    "field_hockey_stick_and_ball": "field_hockey",
    "flag_england": "england",
    "flag_scotland": "scotland",
    "flag_un": "united_nations",
    "flag_wales": "wales",
    "flipper": "dolphin",
    "fr": "flag_fr",
    "fried_egg": "cooking",
    "gb": "flag_gb",
    "giraffe_face": "giraffe",
    "grinning_face_with_one_large_and_one_small_eye": "zany_face",
    "grinning_face_with_star_eyes": "star_struck",
    "hand": "raised_hand",
    "hand_with_index_and_middle_fingers_crossed": "fingers_crossed",
    "heavy_exclamation_mark": "exclamation",
    "hocho": "knife",
    "honeybee": "bee",
    "i_love_you_hand_sign": "love_you_gesture",
    "ice_hockey_stick_and_puck": "hockey",
    "it": "flag_it",
    "jp": "flag_jp",
    "keycap_star": "asterisk",
    "kneeling_person": "person_kneeling",
    "knife_fork_plate": "fork_knife_plate",
    "kr": "flag_kr",
    "ladybug": "lady_beetle",
    "lantern": "izakaya_lantern",
    "large_blue_circle": "blue_circle",
    "large_blue_square": "blue_square",
    "large_brown_circle": "brown_circle",
    "large_brown_square": "brown_square",
    "large_green_circle": "green_circle",
    "large_green_square": "green_square",
    "large_orange_circle": "orange_circle",
    "large_orange_square": "orange_square",
    "large_purple_circle": "purple_circle",
    "large_purple_square": "purple_square",
    "large_red_square": "red_square",
    "large_yellow_circle": "yellow_circle",
    "large_yellow_square": "yellow_square",
    "lightning": "cloud_lightning",
    "lightning_cloud": "cloud_lightning",
    "lotion_bottle": "squeeze_bottle",
    "male_artist": "man_artist",
    "male_astronaut": "man_astronaut",
    "male_construction_worker": "man_construction_worker",
    "male_cook": "man_cook",
    "male_detective": "man_detective",
    "male_doctor": "man_health_worker",
    "male_elf": "man_elf",
    "male_factory_worker": "man_factory_worker",
    "male_fairy": "man_fairy",
    "male_farmer": "man_farmer",
    "male_firefighter": "man_firefighter",
    "male_genie": "man_genie",
    "male_guard": "man_guard",
    "male_judge": "man_judge",
    "male_mage": "man_mage",
    "male_mechanic": "man_mechanic",
    "male_office_worker": "man_office_worker",
    "male_pilot": "man_pilot",
    "male_police_officer": "man_police_officer",
    "male_scientist": "man_scientist",
    "male_singer": "man_singer",
    "male_student": "man_student",
    "male_superhero": "man_superhero",
    "male_supervillain": "man_supervillain",
    "male_teacher": "man_teacher",
    "male_technologist": "man_technologist",
    "male_vampire": "man_vampire",
    "male_zombie": "man_zombie",
    "man_and_woman_holding_hands": "couple",
    "man_boy": "family_man_boy",
    "man_boy_boy": "family_man_boy_boy",
    "man_getting_massage": "man_getting_face_massage",
    "man_girl": "family_man_girl",
    "man_girl_boy": "family_man_girl_boy",
    "man_girl_girl": "family_man_girl_girl",
    "man_heart_man": "couple_with_heart_mm",
    "man_kiss_man": "couplekiss_mm",
    "man_man_boy": "family_mmb",
    "man_man_boy_boy": "family_mmbb",
    "man_man_girl": "family_mmg",
    "man_man_girl_boy": "family_mmgb",
    "man_man_girl_girl": "family_mmgg",
    "man_with_beard": "man_beard",
    "man_with_bunny_ears_partying": "men_with_bunny_ears_partying",
    "man_woman_boy": "family_man_woman_boy",
    "man_woman_boy_boy": "family_mwbb",
    "man_woman_girl": "family_mwg",
    "man_woman_girl_boy": "family_mwgb",
    "man_woman_girl_girl": "family_mwgg",
    "man_wrestling": "men_wrestling",
    "mantelpiece_clock": "clock",
    "mate_drink": "mate",
    "medal": "military_medal",
    "men_holding_hands": "two_men_holding_hands",
    "menorah_with_nine_branches": "menorah",
    "moon": "waxing_gibbous_moon",
    "mostly_sunny": "white_sun_small_cloud",
    "motor_boat": "motorboat",
    "open_book": "book",
    "partly_sunny_rain": "white_sun_rain_cloud",
    "person_with_headscarf": "woman_with_headscarf",
    "phone": "telephone",
    "rain_cloud": "cloud_rain",
    "red_haired_man": "man_red_haired",
    "red_haired_person": "person_red_hair",
    "red_haired_woman": "woman_red_haired",
    "ru": "flag_ru",
    "running": "person_running",
    "satellite": "satellite_orbital",
    "satellite_antenna": "satellite",
    "serious_face_with_symbols_covering_mouth": "face_with_symbols_over_mouth",
    "shocked_face_with_exploding_head": "exploding_head",
    "shoe": "mans_shoe",
    "simple_smile": "slightly_smiling_face",
    "smiling_face_with_smiling_eyes_and_hand_covering_mouth": "face_with_hand_over_mouth",
    "snow_cloud": "cloud_with_snow",
    "snowman": "snowman2",
    "snowman_without_snow": "snowman",
    "spock_hand": "vulcan",
    "staff_of_aesculapius": "medical_symbol",
    "standing_person": "person_standing",
    "sun_behind_cloud": "white_sun_cloud",
    "sun_behind_rain_cloud": "white_sun_rain_cloud",
    "sun_small_cloud": "white_sun_small_cloud",
    "table_tennis_paddle_and_ball": "ping_pong",
    "the_horns": "sign_of_the_horns",
    "thumbsup_all": "thumbsup",
    "tornado": "cloud_with_tornado",
    "tornado_cloud": "cloud_with_tornado",
    "tshirt": "shirt",
    "uk": "flag_gb",
    "umbrella": "umbrella2",
    "umbrella_with_rain_drops": "umbrella",
    "us": "flag_us",
    "waving_black_flag": "flag_black",
    "waving_white_flag": "flag_white",
    "white_haired_man": "man_white_haired",
    "white_haired_person": "person_white_hair",
    "white_haired_woman": "woman_white_haired",
    "woman_and_man_holding_hands": "couple",
    "woman_boy": "family_woman_boy",
    "woman_boy_boy": "family_woman_boy_boy",
    "woman_getting_massage": "woman_getting_face_massage",
    "woman_girl": "family_woman_girl",
    "woman_girl_boy": "family_woman_girl_boy",
    "woman_girl_girl": "family_woman_girl_girl",
    "woman_heart_man": "couple_with_heart_woman_man",
    "woman_heart_woman": "couple_with_heart_ww",
    "woman_kiss_man": "kiss_woman_man",
    "woman_kiss_woman": "couplekiss_ww",
    "woman_with_beard": "woman_beard",
    "woman_with_bunny_ears_partying": "women_with_bunny_ears_partying",
    "woman_woman_boy": "family_wwb",
    "woman_woman_boy_boy": "family_wwbb",
    "woman_woman_girl": "family_wwg",
    "woman_woman_girl_boy": "family_wwgb",
    "woman_woman_girl_girl": "family_wwgg",
    "woman_wrestling": "women_wrestling",
    "women_holding_hands": "two_women_holding_hands",
    "zebra_face": "zebra",
}
